@@ -10,6 +10,7 @@
 
 import plugins
 from pyutilib.component.core import *
+import sys
 
 
 class DefaultTestDriver(Plugin):
@@ -36,6 +37,7 @@ class DefaultTestDriver(Plugin):
     def tearDown(self, testcase, options):
         """Tear-down a single test in the suite"""
         #print 'tearDown',options
+        sys.stdout.flush()
 
     def run_test(self, testcase, name, options):
         """Execute a single test in the suite"""
